.. _http-clients:

************
HTTP clients
************

Mopidy added an :ref:`http-frontend` in 0.10 which provides the building blocks
needed for creating web clients for Mopidy with the help of a WebSocket and a
JavaScript library provided by Mopidy.

This page will list any HTTP/web Mopidy clients. If you've created one, please
notify us so we can include your client on this page.

See :ref:`http-frontend` for details on how to build your own web client.
